import AutoRPE.UtilsRPE.VariablePrecision as VariablePrecision
import AutoRPE.UtilsRPE.Vault as Vault
import AutoRPE.UtilsRPE.TrackDependency as TrackDependency


def get_command_line_arguments():
    import argparse

    parser = argparse.ArgumentParser()
    parser.add_argument("-i", "--input-source", required=True, type=PathType(exists=True, type="dir"),
                        help="Path to clean input fortran files")
    parser.add_argument("-o", "--output-vault", default="vault.pkl",
                        help="Name of the output vault file")
    parser.add_argument("-w", "--working-precision", default='dp',
                        help="The precision used for real numbers in the parsed code")

    args = parser.parse_args()

    try:
        VariablePrecision.real_id[args.working_precision]
    except KeyError:
        parser.error("Argument -w/--working precision has the wrong format. Use one in " +
                     "[" + ", ".join([*VariablePrecision.real_id])+"]")
    return args


if __name__ == "__main__":

    args = get_command_line_arguments()

    path_to_input_sources = args.input_source
    output_vault = args.output_vault

    # Set the proper working precision
    VariablePrecision.set_working_precision(args.working_precision)

    # Parse input sources and stores info in vault
    print("Creating a database from sources found in:\n %s" % path_to_input_sources)
    vault = Vault.create_database(path_to_input_sources)

    # Store the dependencies btw variables, and create a graph for visualization
    TrackDependency.propagate_dependencies(vault, "./graph.gexf")

    # Save the vault with the variable precisions updated.
    vault.save(output_vault)
