import unittest
import AutoRPE.UtilsRPE.Splitter as Splitter

class TestSplitter(unittest.TestCase):
    def test_separate_line_container_and_arguments_1(self):
        string = 'write(numicb,*) \'bergstep \',nktberg,\' send ns: \', ibergs_to_send_n, ibergs_to_send_s'

        line_container, arguments = Splitter.split_line_container_and_arguments(string=string)
        actual_arguments = ["'bergstep '", 'nktberg', "' send ns: '", ' ibergs_to_send_n', ' ibergs_to_send_s']
        actual_line_container = 'write(numicb,*) ###TOREPLACE###'

        self.assertTrue(line_container == actual_line_container and actual_arguments == arguments)

    def test_separate_line_container_and_arguments_2(self):
        string = "WRITE(cl_asmbkg, FMT='(A,\".nc\")' ) TRIM( c_asmbkg )"

        line_container, arguments = Splitter.split_line_container_and_arguments(string=string)
        actual_arguments = ['TRIM( c_asmbkg )']
        actual_line_container = 'WRITE(cl_asmbkg, FMT=\'(A,".nc")\' ) ###TOREPLACE###'

        self.assertTrue(line_container == actual_line_container and actual_arguments == arguments)

    def test_separate_line_container_and_arguments_3(self):
        string = "IF(lwp) WRITE(numout,'(a,i6,a,i2,a,i2,a,i8,a,i8,a,i8,a,i8)')                   ' =======>> 1/2 time step before the start of the run DATE Y/M/D = ',                   nyear, '/', nmonth, '/', nday, '  nsec_day:', nsec_day, '  nsec_monday:', nsec_monday, '                   nsec_month:', nsec_month , '  nsec_year:' , nsec_year"
        line_container, arguments = Splitter.split_line_container_and_arguments(string=string)
        condition = arguments[0].count("WRITE") == 0
        self.assertTrue(condition)

    def test_separate_line_container_and_arguments_4(self):
        string = 'IF( lwriter ) WRITE(numtime,*) \'        ===> W A R N I N G: \''
        line_container, arguments = Splitter.split_line_container_and_arguments(string=string)
        condition = arguments[0].count("WRITE") == 0
        self.assertTrue(condition)

    def test_separate_line_container_and_arguments_4(self):
        string = 'IF (ln_grid_search_lookup)WRITE(numout,*) \'      Grid search lookup file header                cn_gridsearchfile = \', cn_gridsearchfile'
        line_container, arguments = Splitter.split_line_container_and_arguments(string=string)
        condition = arguments[0].count("WRITE") == 0
        self.assertTrue(condition)


if __name__ == '__main__':
    unittest.main()
